Structs
- Apply
Result - Result of applying a sync patch to a database.
Functions
- apply_
patch - Apply a sync patch to a database via TxnManager.
- apply_
patch_ to_ table - Apply a sync patch to a named table, creating it if needed.
- apply_
patch_ to_ table_ txn - Apply a sync patch to a named table within an existing write transaction.
- apply_
patch_ to_ txn - Apply a sync patch within an existing write transaction.