HlcClock

Struct HlcClock 

pub struct HlcClock<C: PhysicalClock = SystemClock> { /* private fields */ }
Hybrid Logical Clock state machine.

Two core operations:

  • now() - generate a timestamp for a local event
  • update() - merge a remote timestamp into local state

now() always returns a strictly increasing timestamp. update() advances the internal clock state without generating a new timestamp. Timestamps are only generated by local events; received timestamps only advance the clock.

Implementations

Source

impl HlcClock<SystemClock>

pub fn new() -> Self

Source

impl<C: PhysicalClock> HlcClock<C>

pub fn with_clock(clock: C) -> Self

pub fn set_max_drift_ns(&mut self, max_drift_ns: i64)

pub fn set_last(&mut self, ts: HlcTimestamp)

Call on startup to restore monotonicity after a restart.

pub fn now(&mut self) -> Result<HlcTimestamp, ClockError>

Generate a monotonically increasing timestamp for a local event.

pub fn update(&mut self, remote: HlcTimestamp) -> Result<(), ClockError>

Merge a remote timestamp into local state (does not generate a new timestamp).

pub fn last_timestamp(&self) -> HlcTimestamp

pub fn physical_clock(&self) -> &C